@@ -229,8 +229,8 @@ fn scan_and_bump_states() -> Option<BumpedStates> {
     let mut should_notify = (store.states.status != Status::Dead && general_status == Status::Dead)
         || (store.states.status == Status::Dead && general_status != Status::Dead);
 
-    // Reset the backoff counter when we are back to healthy
-    if general_status == Status::Healthy && store.states.status != general_status {
+    // Reset the backoff counter whenever we are not dead (yet, stored status changed)
+    if has_changed == true && general_status != Status::Dead {
         store.states.notifier.reminder_backoff_counter = 1;
     }
 
