@@ -7,7 +7,6 @@
 use std::net::SocketAddr;
 use std::path::PathBuf;
 
-use serde_derive::{Deserialize, Serialize};
 use url_serde::SerdeUrl;
 
 use super::defaults;
@@ -34,7 +33,7 @@ pub struct ConfigServer {
     pub inet: SocketAddr,
 
     #[serde(default = "defaults::server_workers")]
-    pub workers: u16,
+    pub workers: usize,
 
     pub reporter_token: String,
 }
@@ -103,6 +102,13 @@ pub struct ConfigNotify {
     pub startup_notification: bool,
 
     pub reminder_interval: Option<u64>,
+
+    #[serde(default = "defaults::notify_reminder_backoff_function")]
+    pub reminder_backoff_function: ConfigNotifyReminderBackoffFunction,
+
+    #[serde(default = "defaults::notify_reminder_backoff_limit")]
+    pub reminder_backoff_limit: u16,
+
     pub email: Option<ConfigNotifyEmail>,
     pub twilio: Option<ConfigNotifyTwilio>,
     pub slack: Option<ConfigNotifySlack>,
@@ -115,6 +121,21 @@ pub struct ConfigNotify {
     pub webhook: Option<ConfigNotifyWebHook>,
 }
 
+#[derive(Serialize, Deserialize, Debug, Clone, Copy, PartialEq)]
+pub enum ConfigNotifyReminderBackoffFunction {
+    #[serde(rename = "none")]
+    None = 0,
+
+    #[serde(rename = "linear")]
+    Linear = 1,
+
+    #[serde(rename = "square")]
+    Square = 2,
+
+    #[serde(rename = "cubic")]
+    Cubic = 3,
+}
+
 #[derive(Deserialize)]
 pub struct ConfigPlugins {
     pub rabbitmq: Option<ConfigPluginsRabbitMQ>,
